<?php
/**
 * sgds Theme Customizer
 *
 * @package sgds
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function sgds_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'sgds_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'sgds_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'sgds_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function sgds_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function sgds_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if ( ! function_exists( 'sgds_theme_customize_register' ) ) {
	/**
	 * Register individual settings through customizer's API.
	 *
	 * @param WP_Customize_Manager $wp_customize Customizer reference.
	 */
	function sgds_theme_customize_register( $wp_customize ) {
		// Theme layout settings.
		$wp_customize->add_section(
			'sgds_theme_layout_options',
			array(
				'title'       => __( 'SGDS Container Setting', 'sgds' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Container width and sidebar defaults', 'sgds' ),
				'priority'    => 160,
			)
		);
		/**
		 * Select sanitization function
		 *
		 * @param string               $input   Slug to sanitize.
		 * @param WP_Customize_Setting $setting Setting instance.
		 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
		 */
		function sgds_theme_slug_sanitize_select( $input, $setting ) {
			// Ensure input is a slug (lowercase alphanumeric characters, dashes and underscores are allowed only).
			$input = sanitize_key( $input );
			// Get the list of possible select options.
			$choices = $setting->manager->get_control( $setting->id )->choices;
				// If the input is a valid key, return it; otherwise, return the default.
				return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
		}
		$wp_customize->add_setting(
			'sgds_container_type',
			array(
				'default'           => '',
				'type'              => 'theme_mod',
				'sanitize_callback' => 'sgds_theme_slug_sanitize_select',
				'capability'        => 'edit_theme_options',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Control(
				$wp_customize,
				'sgds_container_type',
				array(
					'label'       => __( 'Container Width', 'sgds' ),
					'description' => __( 'Choose container or container is-fluid', 'sgds' ),
					'section'     => 'sgds_theme_layout_options',
					'settings'    => 'sgds_container_type',
					'type'        => 'select',
					'choices'     => array(
						''       => __( 'Fixed width container', 'sgds' ),
						'is-fluid' => __( 'Full width container', 'sgds' ),
					),
					'priority'    => '10',
				)
			)
		);
		// $wp_customize->add_setting(
		// 	'sgds_sidebar_position',
		// 	array(
		// 		'default'           => 'right',
		// 		'type'              => 'theme_mod',
		// 		'sanitize_callback' => 'sanitize_text_field',
		// 		'capability'        => 'edit_theme_options',
		// 	)
		// );
		// $wp_customize->add_control(
		// 	new WP_Customize_Control(
		// 		$wp_customize,
		// 		'sgds_sidebar_position',
		// 		array(
		// 			'label'             => __( 'Sidebar Positioning', 'sgds' ),
		// 			'description'       => __(
		// 				'Set sidebar\'s default position. Can either be: right, left, both or none. Note: this can be overridden on individual pages.',
		// 				'sgds'
		// 			),
		// 			'section'           => 'sgds_theme_layout_options',
		// 			'settings'          => 'sgds_sidebar_position',
		// 			'type'              => 'select',
		// 			'sanitize_callback' => 'sgds_theme_slug_sanitize_select',
		// 			'choices'           => array(
		// 				'right' => __( 'Right sidebar', 'sgds' ),
		// 				'left'  => __( 'Left sidebar', 'sgds' ),
		// 				'both'  => __( 'Left & Right sidebars', 'sgds' ),
		// 				'none'  => __( 'No sidebar', 'sgds' ),
		// 			),
		// 			'priority'          => '20',
		// 		)
		// 	)
		// );
	}
} // endif function_exists( 'sgds_theme_customize_register' ).
add_action( 'customize_register', 'sgds_theme_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function sgds_customize_preview_js() {
	wp_enqueue_script( 'sgds-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'sgds_customize_preview_js' );
